DataSetType
===========

.. currentmodule:: wwt_data_formats.enums

.. autoclass:: DataSetType
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~DataSetType.EARTH
      ~DataSetType.PANORAMA
      ~DataSetType.PLANET
      ~DataSetType.SANDBOX
      ~DataSetType.SKY
      ~DataSetType.SOLAR_SYSTEM

   .. rubric:: Attributes Documentation

   .. autoattribute:: EARTH
   .. autoattribute:: PANORAMA
   .. autoattribute:: PLANET
   .. autoattribute:: SANDBOX
   .. autoattribute:: SKY
   .. autoattribute:: SOLAR_SYSTEM
